# Hello World
This is an example of how to publish a python module to PyPI

## Installation
To install type:
```python
$ pip install helloworld-nhenseler
```

## Usage
```python
from helloworld-nhenseler import say_hello

# Generate "Hello, World!"
say_hello()

# Generate "Hello, Everybody!"
say_hello("Everybody")
```